==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/pl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Udostępnianie Stowarzyszone",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcesz się dzielić zdalnie {name} z {owner}@{remote}?",
    "Remote share" : "Zdalny zasób",
    "Remote share password" : "Hasło do zdalnego zasobu",
    "Cancel" : "Anuluj",
    "Add remote share" : "Dodaj zdalny zasób",
    "Copied!" : "Skopiowano!",
    "Not supported!" : "Brak wsparcia!",
    "Press ⌘-C to copy." : "Wciśnij ⌘-C by skopiować.",
    "Press Ctrl-C to copy." : "Wciśnij Ctrl-C by skopiować.",
    "Invalid Federated Cloud ID" : "Nieprawidłowy identyfikator Stowarzyszonej Chmury",
    "Server to server sharing is not enabled on this server" : "Serwer do udostępniania serwera nie jest włączony na tym serwerze",
    "Couldn't establish a federated share." : "Nie udało się ustalić Stowarzyszonego udostępnienia.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nie udało się ustalić Stowarzyszonego udostępnienia, może być błędne hasło.",
    "Federated Share request was successful, you will receive a invitation. Check your notifications." : "Żądanie podzielenia się ze Stowarzyszeniem powiedzie się, gdy otrzymasz zaproszenie. Sprawdź swoje powiadomienia.",
    "The mountpoint name contains invalid characters." : "Nazwa zamontowanego zasobu zawiera niedozwolone znaki.",
    "Not allowed to create a federated share with the owner." : "Nie można tworzyć stowarzyszonego udziału ze sobą.",
    "Invalid or untrusted SSL certificate" : "Niewłaściwy lub niezaufany certyfikat SSL",
    "Could not authenticate to remote share, password might be wrong" : "Nie udało się uwierzytelnić udziału zdalnego, może być błędne hasło",
    "Storage not valid" : "Zasób nie jest prawidłowy",
    "Federated Share successfully added" : "Udane udostępnienie ze Stowarzyszeniem ",
    "Couldn't add remote share" : "Nie można dodać zdalnego zasobu",
    "Sharing %s failed, because this item is already shared with %s" : "Współdzielenie %s nie powiodło się, ponieważ element jest już współdzielony z %s",
    "Not allowed to create a federated share with the same user" : "Nie można tworzyć stowarzyszonego udziału z tym samym użytkownikiem",
    "File is already shared with %s" : "Plik jest już współdzielony z %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Dzielenie %s nie powiodło się. Nie można było znaleźć %s, być może serwer jest obecnie nieosiągalny lub używa certyfikatu z podpisem własnym.",
    "Could not find share" : "Nie można znaleźć powiązania",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Otrzymałeś \"%3$s\" w zdalnym udziale z %1$s (w imieniu %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Otrzymałeś {share} w zdalnym udziale z {user} (w imieniu {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Otrzymałeś \"%3$s\" w zdalnym udziale %1$s",
    "You received {share} as a remote share from {user}" : "Otrzymałeś {share} w zdalnym udziale {user}",
    "Accept" : "Akceptuj",
    "Decline" : "Utrata",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Podziel się ze mną przez mój ID #Nextcloud Stowarzyszonej Chmury, zobacz %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Podziel się ze mną przez mój ID #Nextcloud Stowarzyszonej Chmury",
    "Federated Cloud Sharing" : "Dzielenie się ze Stowarzyszoną Chmurą",
    "Open documentation" : "Otwórz dokumentację",
    "Allow users on this server to send shares to other servers" : "Zezwalaj użytkownikom na tym serwerze wysłać udostępnienia do innych serwerów",
    "Allow users on this server to receive shares from other servers" : "Zezwalaj użytkownikom na tym serwerze do otrzymania udostępnień z innych serwerów",
    "Federated Cloud" : "Stowarzyszona Chmura",
    "Your Federated Cloud ID:" : "Twoje ID Stowarzyszonej Chmury:",
    "Share it:" : "Udostępnij to:",
    "Add to your website" : "Dodaj do swojej strony",
    "Share with me via Nextcloud" : "Podziel się ze mną poprzez Nextcloud",
    "HTML Code:" : "Kod HTML:",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Współdzielenie %s nie powiodło się, nie można odnaleźć %s. Prawdopobnie serwer nie jest teraz osiągalny.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Otrzymałeś \"/%3$s\" w zdalnym udziale z %1$s (w imieniu %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Otrzymałeś \"/%3$s\" w zdalnym udziale z %1$s"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-11.0.4.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/pl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Udostępnianie Stowarzyszone",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcesz się dzielić zdalnie {name} z {owner}@{remote}?",
    "Remote share" : "Zdalny zasób",
    "Remote share password" : "Hasło do zdalnego zasobu",
    "Cancel" : "Anuluj",
    "Add remote share" : "Dodaj zdalny zasób",
    "Copy" : "Skopiuj",
    "Copied!" : "Skopiowano!",
    "Not supported!" : "Brak wsparcia!",
    "Press ⌘-C to copy." : "Wciśnij ⌘-C by skopiować.",
    "Press Ctrl-C to copy." : "Wciśnij Ctrl-C by skopiować.",
    "Invalid Federated Cloud ID" : "Nieprawidłowy identyfikator Stowarzyszonej Chmury",
    "Server to server sharing is not enabled on this server" : "Serwer do udostępniania serwera nie jest włączony na tym serwerze",
    "Couldn't establish a federated share." : "Nie udało się ustalić Stowarzyszonego udostępnienia.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nie udało się ustalić Stowarzyszonego udostępnienia, może być błędne hasło.",
    "The mountpoint name contains invalid characters." : "Nazwa zamontowanego zasobu zawiera niedozwolone znaki.",
    "Not allowed to create a federated share with the owner." : "Nie można tworzyć stowarzyszonego udziału ze sobą.",
    "Invalid or untrusted SSL certificate" : "Niewłaściwy lub niezaufany certyfikat SSL",
    "Could not authenticate to remote share, password might be wrong" : "Nie udało się uwierzytelnić udziału zdalnego, może być błędne hasło",
    "Storage not valid" : "Magazyn nie jest prawidłowy",
    "Couldn't add remote share" : "Nie można dodać zdalnego zasobu",
    "Sharing %s failed, because this item is already shared with %s" : "Współdzielenie %s nie powiodło się, ponieważ element jest już współdzielony z %s",
    "Not allowed to create a federated share with the same user" : "Nie można tworzyć stowarzyszonego udziału z tym samym użytkownikiem",
    "File is already shared with %s" : "Plik jest już współdzielony z %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Dzielenie %s nie powiodło się. Nie można było znaleźć %s, być może serwer jest obecnie nieosiągalny lub używa certyfikatu z podpisem własnym.",
    "Could not find share" : "Nie można znaleźć powiązania",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Otrzymałeś \"%3$s\" w zdalnym udziale z %1$s (w imieniu %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Otrzymałeś {share} w zdalnym udziale z {user} (w imieniu {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Otrzymałeś \"%3$s\" w zdalnym udziale %1$s",
    "You received {share} as a remote share from {user}" : "Otrzymałeś {share} w zdalnym udziale {user}",
    "Accept" : "Akceptuj",
    "Decline" : "Utrata",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Podziel się ze mną przez mój ID #Nextcloud Stowarzyszonej Chmury, zobacz %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Podziel się ze mną przez mój ID #Nextcloud Stowarzyszonej Chmury",
    "Sharing" : "Udostępnianie",
    "Federated file sharing" : "Udostępnianie plików chmury stowarzyszonej",
    "Federated Cloud Sharing" : "Dzielenie się ze Stowarzyszoną Chmurą",
    "Open documentation" : "Otwórz dokumentację",
    "Adjust how people can share between servers." : "Dostosuj ustawienia współdzielenia między serwerami.",
    "Allow users on this server to send shares to other servers" : "Zezwalaj użytkownikom na tym serwerze wysłać udostępnienia do innych serwerów",
    "Allow users on this server to receive shares from other servers" : "Zezwalaj użytkownikom na tym serwerze do otrzymania udostępnień z innych serwerów",
    "Search global and public address book for users" : "Szukaj użytkowników w globalnej i publicznej książce adresowej",
    "Allow users to publish their data to a global and public address book" : "Pozwól użytkownikom na publikację ich danych do globalnej i publicznej książki adresowej",
    "Federated Cloud" : "Stowarzyszona Chmura",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Możesz współdzielić z każdym kto używa Nextclouda, ownClouda lub Pydio. Wystarczy, że wpiszesz ich ID chmury stowarzyszonej w pole współdzielenia. Wygląda jak osoba@przyklad.chmury.com",
    "Your Federated Cloud ID:" : "Twoje ID Stowarzyszonej Chmury:",
    "Share it so your friends can share files with you:" : "Współdziel to, aby twoi przyjaciele mogli współdzielić pliki z tobą:",
    "Add to your website" : "Dodaj do swojej strony",
    "Share with me via Nextcloud" : "Podziel się ze mną poprzez Nextcloud",
    "HTML Code:" : "Kod HTML:",
    "Search global and public address book for users and let local users publish their data" : "Szukaj użytkowników w globalnej i publicznej książce adresowej i pozwól lokalnym użytkownikom na publikowanie swoich danych",
    "Share it:" : "Udostępnij to:"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
